"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _lodash = _interopRequireDefault(require("lodash"));

var _util = require("../util");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getArrayItems = ({
  elements
}) => _lodash.default.map(elements, ({
  value
}) => value);

const propVisitor = {
  AssignmentExpression(path, state) {
    const identifier = (0, _util.getExpressionIdentifier)(path);

    const right = _lodash.default.get(path, 'node.right');

    if (!state.hasEntry(identifier)) return;

    if ((0, _util.isValidExpression)(path, ['handledProps']) && (0, _util.isArrayValue)(right)) {
      state.addProps(identifier, getArrayItems(right));
      path.remove();
      return;
    }

    if ((0, _util.isValidExpression)(path, ['defaultProps', 'propTypes']) && (0, _util.isObjectValue)(right)) {
      state.addProps(identifier, (0, _util.getObjectKeys)(right));
    }
  },

  ClassProperty(path, state) {
    const expression = (0, _util.getClassDeclaration)(path);
    const identifier = (0, _util.getEntryIdentifier)(expression);

    const value = _lodash.default.get(path, 'node.value');

    if (!state.hasEntry(identifier) || !(0, _util.isStaticProperty)(path)) return;

    if ((0, _util.isValidProperty)(path, ['handledProps']) && (0, _util.isArrayValue)(value)) {
      state.addProps(identifier, getArrayItems(value));
      path.remove();
      return;
    }

    if ((0, _util.isValidProperty)(path, ['defaultProps', 'propTypes']) && (0, _util.isObjectValue)(value)) {
      state.addProps(identifier, (0, _util.getObjectKeys)(value));
    }
  }

};
var _default = propVisitor;
exports.default = _default;